import React, { useState, useEffect } from 'react';
import { Form, Select, Input, Button, Popconfirm, Spin } from 'antd';
import { modifyProduct } from '@/services/webConfig/api';
const { Item } = Form;
const { Option } = Select;
const EditForm = props => {
  const { productObj, editCallback, handleDel } = props;
  const [config, setConfig] = useState(''); // 网站配置信息
  const [loading, setLoading] = useState(false);
  const [form] = Form.useForm();
  const layout = {
    layout: 'horizontal',
    labelCol: { span: 4 },
    wrapperCol: { span: 15 },
  };
  const environmentList = [
    {
      value: 'production',
      label: '生产环境',
      key: 'production',
    },
    {
      value: 'development',
      label: '开发环境',
      key: 'development',
    },
  ];
  useEffect(() => {
    form.setFieldsValue({ ...productObj });
  }, [productObj]);
  // 提交选择
  const submit = value => {};
  // 提交
  const finished = value => {
    let params = {
      ...value,
      Id: productObj.Id,
    };
    editCallback(params);
    console.log(value, 'value');
  };
  return (
    <Spin spinning={loading} tip="loading...">
      <div style={{ minHeight: 'calc(100vh  - 252px)', marginTop: '20px' }}>
        <Form form={form} name="formEdit" {...layout} onFinish={finished}>
          <Item
            label="产品名称："
            name="ProductName"
            rules={[
              {
                required: true,
                message: '请输入产品名称',
              },
            ]}
          >
            <Input placeholder="请输入产品名称" allowClear />
          </Item>

          <Item
            label="产品环境："
            name="Environment"
            rules={[
              {
                required: true,
                message: '请选择产品环境',
              },
            ]}
          >
            <Select placeholder="请选择产品环境">
              {environmentList &&
                environmentList.map(item => (
                  <Option value={item.value} key={item.key}>
                    {item.label}
                  </Option>
                ))}
            </Select>
          </Item>
          <Item
            label="入口url"
            name="StartUrl"
            rules={[
              {
                required: true,
                message: '请输入入口url',
              },
            ]}
          >
            <Input addonBefore="//" placeholder="请输入入口url" allowClear />
          </Item>
          <Item
            label="默认配置"
            name="DefaultSetting"
            rules={[
              {
                required: false,
                message: '请输入默认配置',
              },
            ]}
          >
            <Input placeholder="请输入默认配置" allowClear />
          </Item>
          <div style={{ display: 'flex', marginLeft: '35%' }}>
            <Item
              wrapperCol={{ span: 8, offset: 8 }}
              style={{ marginRight: '30px' }}
            >
              <Button type="primary" htmlType="submit">
                提交
              </Button>
            </Item>
            {/* <Item wrapperCol={{ span: 8, offset: 8 }}>
              <Popconfirm
                title="确实删除产品"
                placement="right"
                okText="确认"
                cancelText="取消"
                onConfirm={handleDel}
              >
                <Button type="primary" danger>
                  删除
                </Button>
              </Popconfirm>
            </Item> */}
          </div>
        </Form>
      </div>
    </Spin>
  );
};
export default EditForm;
