import React from 'react';
import {
  DatabaseOutlined,
  UsergroupAddOutlined,
  SettingOutlined,
  HomeOutlined,
  SolutionOutlined,
  //   AndroidOutlined,
  //   CommentOutlined,
  TableOutlined,
  CopyOutlined,
} from '@ant-design/icons';
import UserLayout from '../layouts/UserLayout';
import Login from '../pages/user/login';
import BasicLayout from '../layouts/BasicLayout';
import BlankLayout from '../layouts/BlankLayout';
import RequestTest from '../pages/testPages/request';
import InitDataBase from '../pages/database/InitDataBase';
import ManagementDataBase from '../pages/database/ManagementDataBase';
import DatabaseConnectConfig from '@/pages/database/databaseConfig/DatabaseConfig';
import CurrentSolution from '@/pages/database/CurrentSolution';
import UserManage from '../pages/userCenter/userManage/UserManage';
import RoleManage from '@/pages/userCenter/roleManage/RoleManage';
import SiteManage from '../pages/userCenter/siteManage/SiteManage';
import Dictionary from '../pages/dataCenter/dictionary';
import ServiceLog from '../pages/log/serviceLog';
import LoginLog from '../pages/log/loginLog';
import OmsLog from '../pages/log/omsLog';
// import DefaultComponent from '../pages/orgnazation/DefaultComponent';
import TestTable from '../pages/orgnazation/TestTable';
import WebConfigPage from '@/pages/webConfig';
// import AppConfigPage from '@/pages/appConfig';
import MobileConfigPage from '@/pages/mobileConfig';
import { USER_MODE } from '@/utils/constants';
import BaseFrameContainer from '@/components/BaseFrameContainer';
import JumpContainer from '@/components/JumpContainer';
// import ColConen from '@/components/Colophon/colContent';

const iconStyle = { verticalAlign: '0.125em' };

const superAuthority = [USER_MODE.SUPER];
const adminAuthority = [...superAuthority, USER_MODE.ADMIN];
// const commonAuthority = [...adminAuthority, USER_MODE.COMMON];

export default {
  routes: [
    {
      path: '/user',
      component: UserLayout,
      hideMenu: true,
      routes: [
        {
          name: 'login',
          path: '/user/login',
          component: Login,
        },
      ],
    },
    {
      path: '/test/request',
      hideMenu: true,
      component: RequestTest,
    },
    {
      path: '/',
      component: BasicLayout,
      routes: [
        {
          path: '/solution',
          name: '解决方案管理',
          icon: <SolutionOutlined style={iconStyle} />,
          authority: superAuthority,
          component: CurrentSolution,
        },
        {
          path: '/dbm',
          name: '数据库管理',
          icon: <DatabaseOutlined style={iconStyle} />,
          component: BlankLayout,
          authority: adminAuthority,
          routes: [
            {
              path: '/dbm/dbInit',
              name: '数据库连接',
              authority: adminAuthority,
              component: InitDataBase,
            },
            {
              path: '/dbm/dbsm',
              name: '数据库标准化管理',
              authority: adminAuthority,
              component: ManagementDataBase,
            },
            {
              path: '/dbm/connectConfig',
              name: '数据库连接配置',
              authority: adminAuthority,
              component: DatabaseConnectConfig,
            },
          ],
        },
        {
          path: '/userCenter',
          name: '用户中心',
          component: BlankLayout,
          icon: <UsergroupAddOutlined style={iconStyle} />,
          routes: [
            {
              path: '/userCenter/UserManage',
              name: '用户管理',
              component: UserManage,
            },
            {
              path: '/userCenter/RoleManage',
              name: '角色管理',
              component: RoleManage,
            },
            {
              path: '/userCenter/SiteManage',
              name: '站点管理',
              component: SiteManage,
            },
          ],
        },
        {
          path: '/userCenter/testTable',
          name: '测试表格',
          hideMenu: true,
          component: TestTable,
        },
        {
          path: '/platformCenter',
          component: BlankLayout,
          name: '平台中心',
          icon: <SettingOutlined style={iconStyle} />,
          routes: [
            {
              path: '/platformCenter/gis',
              name: 'GIS平台',
              component: BaseFrameContainer,
              tabs: [
                {
                  tabName: '范围配置',
                  url:
                    '/web4/?widget=product/Tool/EditBoundary/EditBoundary&serverCollextion=JiangNing_JNGW&solution=熊猫智慧水务平台',
                },
                {
                  tabName: '方案配置',
                  url:
                    '/web4/?widget=product/Tool/MapSettings/MapSettings|hideMap=true',
                },
                {
                  tabName: '七参数配置',
                  type: 'sevenParams',
                },
              ],
            },
            {
              path: '/platformCenter/iot',
              name: '物联平台',
              component: BaseFrameContainer,
              tabs: [
                {
                  tabName: '模型类型',
                  url:
                    '/web4/?widget=configuration/ConfigurationsOperationV1/ModelTypeManage/ModelTypeManage|hideMap=true',
                },
                {
                  tabName: '模型文件',
                  url:
                    '/web4/?widget=configuration/ConfigurationsOperationV1/ModelFileManage/ModelFileManage|hideMap=true',
                },
                {
                  tabName: '画板管理',
                  url:
                    '/web4/?widget=configuration/ConfigurationsOperationV1/DrawBoardManage/DrawBoardManage|hideMap=true',
                },
              ],
            },
            {
              path: '/platformCenter/order',
              name: '业务平台',
              component: JumpContainer,
            },
            {
              path: '/platformCenter/notify',
              name: '消息平台',
              component: BaseFrameContainer,
              tabs: [
                {
                  tabName: '推送模板配置',
                  url:
                    '/web4/?widget=product/oms/MessageTem/MessageTem|hideMap=true&state=scan',
                },
                {
                  tabName: '推送方案配置',
                  url:
                    '/web4/?widget=product/oms/MessageConfig/MessageConfig|hideMap=true',
                },
              ],
            },
            {
              path: '/platformCenter/emq',
              name: '宿主管理',
              url:
                '/web4/?widget=product/oms/MqttConfig/MqttConfig.js|hideMap=true',
              component: BaseFrameContainer,
            },
          ],
        },
        {
          path: '/productCenter',
          component: BlankLayout,
          name: '应用中心',
          icon: <HomeOutlined style={iconStyle} />,
          routes: [
            {
              path: '/productCenter/web',
              name: 'Web配置',
              component: WebConfigPage,
            },
            {
              path: '/productCenter/app',
              name: '移动应用配置',
              component: MobileConfigPage,
            },
          ],
        },
        {
          path: '/dataCenter',
          name: '数据中心',
          icon: <TableOutlined style={iconStyle} />,
          component: BlankLayout,
          routes: [
            {
              path: '/dataCenter/dictionary',
              name: '数据字典',
              component: Dictionary,
            },
            {
              path: '/dataCenter/video',
              name: '视频管理',
              url:
                '/web4/?widget=product/oms/VideoConfig/VideoConfig|hideMap=true&videoType=萤石云',
              component: BaseFrameContainer,
            },
          ],
        },
        {
          path: '/log',
          component: BlankLayout,
          name: '系统日志',
          icon: <CopyOutlined style={iconStyle} />,
          routes: [
            {
              path: '/log/service',
              name: '服务监控',
              component: ServiceLog,
            },
            {
              path: '/log/login',
              name: '登录日志',
              component: LoginLog,
            },
            {
              path: '/log/omsLog',
              name: '运维痕迹',
              component: OmsLog,
            },
          ],
        },
      ],
    },
  ],
};
